@@ -1,8 +1,8 @@
 package Test2::Plugin::IOMuxer::STDOUT;
 
-our $VERSION = '0.000008';
+our $VERSION = '0.000009';
 
-use parent 'Test2::Plugin::IOMuxer::Layer';
+use base 'Test2::Plugin::IOMuxer::Layer';
 
 sub name { 'stdout' }
 
